@@ -40,6 +40,8 @@ const parser = (() => {
         '<=': 40,
         '>=': 40,
         '~>': 40,
+        '?:': 40,
+        '??': 40,
         'and': 30,
         'or': 25,
         'in': 40,
@@ -198,6 +200,16 @@ const parser = (() => {
                 position += 2;
                 return create('operator', '~>');
             }
+            if (currentChar === '?' && path.charAt(position + 1) === ':') {
+                // ?: default / elvis operator
+                position += 2;
+                return create('operator', '?:');
+            }
+            if (currentChar === '?' && path.charAt(position + 1) === '?') {
+                // ?? coalescing operator
+                position += 2;
+                return create('operator', '??');
+            }
             // test for single char operators
             if (Object.prototype.hasOwnProperty.call(operators, currentChar)) {
                 position++;
@@ -566,6 +578,20 @@ const parser = (() => {
         prefix("-"); // unary numeric negation
         infix("~>"); // function application
 
+        // coalescing operator
+        infix("??", operators['??'], function (left) {
+            this.type = 'condition';
+            this.condition = {
+                type: 'function',
+                value: '(',
+                procedure: { type: 'variable', value: 'exists' },
+                arguments: [left]
+            };
+            this.then = left;
+            this.else = expression(0);
+            return this;
+        });
+
         infixr("(error)", 10, function (left) {
             this.lhs = left;
 
@@ -849,6 +875,15 @@ const parser = (() => {
             return this;
         });
 
+        // elvis/default operator
+        infix("?:", operators['?:'], function (left) {
+            this.type = 'condition';
+            this.condition = left;
+            this.then = left;
+            this.else = expression(0);
+            return this;
+        });
+
         // object transformer
         prefix("|", function () {
             this.type = 'transform';
