@@ -441,6 +441,13 @@ class Functions:
         if char is None or not char:
             char = " "
 
+        # match JS: truncate width to integer
+        if width is not None:
+            try:
+                width = int(width)
+            except Exception:
+                width = 0
+
         if width < 0:
             result = Functions.left_pad(string, -width, char)
         else:
@@ -722,7 +729,7 @@ class Functions:
         r = None
         for i in range(0, 10):
             try:
-                r = re.sub(pattern, replacement, s, 1)
+                r = re.sub(pattern, replacement, s, count=1)
                 break
             except Exception as e:
                 msg = str(e)
@@ -2010,15 +2017,9 @@ class Functions:
             arg1 = utils.Utils.create_sequence(arg1)
         if not (isinstance(arg2, list)):
             arg2 = utils.Utils.JList([arg2])
-        # else
-        #     // Arg2 was a list: add it as a list element (don't flatten)
-        #     ((List)arg1).add((List)arg2)
 
         arg1 = utils.Utils.JList(arg1)  # create a new copy!
-        if isinstance(arg2, utils.Utils.JList) and arg2.cons:
-            arg1.append(arg2)
-        else:
-            arg1.extend(arg2)
+        arg1.extend(arg2)
         return arg1
 
     @staticmethod
